:tocdepth: 1

#######
Credits
#######
The Multi-threaded Optimization Toolbox is a model optimization toolbox originally meant for diffusion MRI analysis, but
applicable to other fields as well. Software development by Robbert Harms, under the (Phd) supervision of
Alard Roebroeck, at Maastricht University.


************
Contributors
************

* Robbert Harms
    - Lead developer

